@@ -1,7 +1,10 @@
 package App::RL::Command::stat;
+use strict;
+use warnings;
+use autodie;
 
 use App::RL -command;
-use App::RL::Common qw(:all);
+use App::RL::Common;
 
 use constant abstract => 'coverage on chromosomes for runlists';
 
@@ -46,7 +49,7 @@ sub execute {
     #----------------------------#
     # Loading
     #----------------------------#
-    my $length_of = read_sizes( $opt->{size}, $opt->{remove} );
+    my $length_of = App::RL::Common::read_sizes( $opt->{size}, $opt->{remove} );
 
     my $s_of = {};
     my @keys;
@@ -55,13 +58,13 @@ sub execute {
         @keys = sort keys %{$yml};
 
         for my $key (@keys) {
-            $s_of->{$key} = runlist2set( $yml->{$key}, $opt->{remove} );
+            $s_of->{$key} = App::RL::Common::runlist2set( $yml->{$key}, $opt->{remove} );
         }
     }
     else {
         @keys = ("__single");
         $s_of->{__single}
-            = runlist2set( YAML::Syck::LoadFile( $args->[0] ), $opt->{remove} );
+            = App::RL::Common::runlist2set( YAML::Syck::LoadFile( $args->[0] ), $opt->{remove} );
     }
 
     #----------------------------#
